==> opensaml-xmlsec-impl-3.3.1-sources.jar: org/opensaml/xmlsec/signature/impl/SPKIDataUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.xmlsec.signature.SPKIData;

/**
 * A thread-safe Unmarshaller for {@link org.opensaml.xmlsec.signature.SPKIData} objects.
 */
public class SPKIDataUnmarshaller extends AbstractXMLSignatureUnmarshaller {

    /** {@inheritDoc} */
    protected void processChildElement(XMLObject parentXMLObject, XMLObject childXMLObject)
            throws UnmarshallingException {
        SPKIData spkiData = (SPKIData) parentXMLObject;

        // SPKIData contains an unbounded sequence of pairs of a single SPKISexp
        // and an optional, single wildcard <any> element. Let the Validator
        // catch invalid ordering/combinations.
        spkiData.getXMLObjects().add(childXMLObject);
    }

}

==> opensaml-xmlsec-impl-4.3.2-sources.jar: org/opensaml/xmlsec/signature/impl/SPKIDataUnmarshaller.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.xmlsec.signature.impl;

import org.opensaml.core.xml.XMLObject;
import org.opensaml.core.xml.io.UnmarshallingException;
import org.opensaml.xmlsec.signature.SPKIData;

/**
 * A thread-safe Unmarshaller for {@link org.opensaml.xmlsec.signature.SPKIData} objects.
 */
public class SPKIDataUnmarshaller extends AbstractXMLSignatureUnmarshaller {

    /** {@inheritDoc} */
    protected void processChildElement(final XMLObject parentXMLObject, final XMLObject childXMLObject)
            throws UnmarshallingException {
        final SPKIData spkiData = (SPKIData) parentXMLObject;

        // SPKIData contains an unbounded sequence of pairs of a single SPKISexp
        // and an optional, single wildcard <any> element. Let the Validator
        // catch invalid ordering/combinations.
        spkiData.getXMLObjects().add(childXMLObject);
    }

}
